prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_180200 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2018.05.24'
,p_release=>'18.2.0.00.12'
,p_default_workspace_id=>1549777203957536
,p_default_application_id=>100
,p_default_owner=>'APEX_UTILS'
);
end;
/
prompt --application/shared_components/plugins/dynamic_action/com_apexutils_universaltheme
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(28946015191217694891)
,p_plugin_type=>'DYNAMIC ACTION'
,p_name=>'COM.APEXUTILS.UNIVERSALTHEME'
,p_display_name=>' APEX Utils - Universal Theme'
,p_category=>'MISC'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_plsql_code=>wwv_flow_string.join(wwv_flow_t_varchar2(
'/*------------------------------------------------------------------------------',
' * Author       Stefan Dobre',
' * Created      01.06.2019',
' *',
' * Description  A set of dynamic actions related to the Universal Theme &',
' *               user interaction',
' *',
' * License      MIT ',
' *------------------------------------------------------------------------------',
' * Modification History',
' *',
' * 27.06.2019   v1.0.1   fixed success notif duration issue',
' * 24.06.2019   v1.0     initial release',
' */-----------------------------------------------------------------------------',
'function render',
'    ( p_dynamic_action in apex_plugin.t_dynamic_action',
'    , p_plugin         in apex_plugin.t_plugin',
'    )',
'return apex_plugin.t_dynamic_action_render_result',
'is',
'',
'    -- plugin attributes',
'    l_result              apex_plugin.t_dynamic_action_render_result;',
'    l_perform_action      varchar2(100) := p_dynamic_action.attribute_01;',
'    l_scrollto_speed      varchar2(100) := p_dynamic_action.attribute_02;',
'    l_scrollto_duration   varchar2(100) := p_dynamic_action.attribute_03;',
'    l_success_duration    varchar2(100) := p_dynamic_action.attribute_04;',
'    l_autoCollapse        varchar2(100) := p_dynamic_action.attribute_05;',
'',
'    -- variables',
'    l_duration            number;',
'',
'begin',
'    -- debug',
'    apex_plugin_util.debug_dynamic_action',
'        ( p_plugin         => p_plugin',
'        , p_dynamic_action => p_dynamic_action',
'        );',
'',
'    apex_javascript.add_library',
'        ( p_name       => ''script#MIN#''',
'        , p_directory  => nvl(:G_APEX_NITRO_UNIVERSAL_THEME, p_plugin.file_prefix) || ''js/''',
'        );',
'',
'    if l_perform_action = ''scrollto'' then',
'        l_duration := case when l_scrollto_speed != ''custom'' ',
'                        then p_dynamic_action.attribute_02 ',
'                        else p_dynamic_action.attribute_03 ',
'                      end;',
'    elsif l_perform_action = ''configuresuccessnotificationduration'' then',
'        l_duration := l_success_duration;',
'    end if;',
'',
'    l_result.javascript_function := ''apexUtils.universalTheme.exec'';',
'    l_result.attribute_01        := l_perform_action;',
'    ',
'    --For action "Scroll To" or "Configure Success Notification Duration"',
'    l_result.attribute_02        := l_duration;',
'    ',
'    -- autoCollapse Y/N',
'    l_result.attribute_03        := l_autoCollapse;',
'',
'    return l_result;',
'',
'end render;'))
,p_api_version=>2
,p_render_function=>'render'
,p_standard_attributes=>'ITEM:BUTTON:REGION:JQUERY_SELECTOR'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_version_identifier=>'1.0.1'
,p_about_url=>'https://www.apexutils.com'
,p_files_version=>29
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(28948103097931824235)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Action'
,p_attribute_type=>'SELECT LIST'
,p_is_required=>true
,p_default_value=>'collapsenavmenu'
,p_is_translatable=>false
,p_lov_type=>'STATIC'
,p_attribute_comment=>'Choose which action related to the Universal Theme will be performed.'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28948283020614829657)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>10
,p_display_value=>'Navigation Menu - Collapse'
,p_return_value=>'collapsenavmenu'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28948557698385831890)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>20
,p_display_value=>'Navigation Menu - Expand'
,p_return_value=>'expandnavmenu'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28953736895434203087)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>30
,p_display_value=>'Navigation Menu - Collapse Nodes'
,p_return_value=>'collapsenavmenunodes'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28953748951652208347)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>40
,p_display_value=>'Navigation Menu - Expand Nodes'
,p_return_value=>'expandnavmenunodes'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(27558475755790823)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>45
,p_display_value=>'Navigation Menu - Set Node AutoCollapse'
,p_return_value=>'setnavmenunodesautocollapse'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28955934419651223111)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>50
,p_display_value=>'Collapsible Region - Collapse'
,p_return_value=>'collapsecollapsibleregion'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28955944189809225007)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>60
,p_display_value=>'Collapsible Region - Expand'
,p_return_value=>'expandcollapsibleregion'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(27537242300965994)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>65
,p_display_value=>'Maximizable Region - Maximize'
,p_return_value=>'maximizableregionmaximize'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(27537620612968085)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>66
,p_display_value=>'Maximizable Region - Restore'
,p_return_value=>'maximizableregionrestore'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28955992072495231933)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>70
,p_display_value=>'Configure Success Notification Duration'
,p_return_value=>'configuresuccessnotificationduration'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28956073141898237675)
,p_plugin_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_display_sequence=>80
,p_display_value=>'Scroll To Element'
,p_return_value=>'scrollto'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(28978398664619241565)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Speed'
,p_attribute_type=>'SELECT LIST'
,p_is_required=>true
,p_default_value=>'400'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'scrollto'
,p_lov_type=>'STATIC'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28978405899533241124)
,p_plugin_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_display_sequence=>10
,p_display_value=>'Instant'
,p_return_value=>'0'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28978421473948242374)
,p_plugin_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_display_sequence=>20
,p_display_value=>'Slow'
,p_return_value=>'600'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28978426774179243271)
,p_plugin_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_display_sequence=>30
,p_display_value=>'Default'
,p_return_value=>'400'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28978429251254244107)
,p_plugin_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_display_sequence=>40
,p_display_value=>'Fast'
,p_return_value=>'200'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(28978448832792245149)
,p_plugin_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_display_sequence=>50
,p_display_value=>'Custom'
,p_return_value=>'custom'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(28978820673490261869)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>30
,p_prompt=>'Duration'
,p_attribute_type=>'INTEGER'
,p_is_required=>true
,p_default_value=>'400'
,p_unit=>'milliseconds'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(28978398664619241565)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'custom'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(28980379435207385220)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>40
,p_prompt=>'Duration'
,p_attribute_type=>'INTEGER'
,p_is_required=>true
,p_default_value=>'3000'
,p_unit=>'milliseconds'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'configuresuccessnotificationduration'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27568780089811483)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>5
,p_display_sequence=>50
,p_prompt=>'AutoCollapse'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'Y'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(28948103097931824235)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'setnavmenunodesautocollapse'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(27583046326390532)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_name=>'au-ut-apexwindowresized'
,p_display_name=>'APEX Window Resized'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(27584186020390533)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_name=>'au-ut-theme42navmenucollapsed'
,p_display_name=>'Theme 42 Navigation Menu Collapsed'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(27583754149390532)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_name=>'au-ut-theme42navmenuexpanded'
,p_display_name=>'Theme 42 Navigation Menu Expanded'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(27583326347390532)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_name=>'au-ut-theme42ready'
,p_display_name=>'Theme 42 Ready'
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2A2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A202A20417574686F7220202020202020537465';
wwv_flow_api.g_varchar2_table(2) := '66616E20446F6272650A202A204372656174656420202020202030312E30362E323031390A202A0A202A204465736372697074696F6E20204120736574206F662064796E616D696320616374696F6E732072656C6174656420746F2074686520556E6976';
wwv_flow_api.g_varchar2_table(3) := '657273616C205468656D6520260A202A2020202020202020202020202020207573657220696E746572616374696F6E0A202A0A202A204C6963656E73652020202020204D4954200A202A2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D';
wwv_flow_api.g_varchar2_table(4) := '2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A202A204D6F64696669636174696F6E20486973746F72790A202A0A202A2032342E30362E3230313920202076312E30';
wwv_flow_api.g_varchar2_table(5) := '20696E697469616C2072656C656173650A202A2F2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A6675';
wwv_flow_api.g_varchar2_table(6) := '6E6374696F6E2072656E6465720A202020202820705F64796E616D69635F616374696F6E20696E20617065785F706C7567696E2E745F64796E616D69635F616374696F6E0A202020202C20705F706C7567696E202020202020202020696E20617065785F';
wwv_flow_api.g_varchar2_table(7) := '706C7567696E2E745F706C7567696E0A20202020290A72657475726E20617065785F706C7567696E2E745F64796E616D69635F616374696F6E5F72656E6465725F726573756C740A69730A0A202020202D2D20706C7567696E2061747472696275746573';
wwv_flow_api.g_varchar2_table(8) := '0A202020206C5F726573756C742020202020202020202020202020617065785F706C7567696E2E745F64796E616D69635F616374696F6E5F72656E6465725F726573756C743B0A202020206C5F706572666F726D5F616374696F6E202020202020766172';
wwv_flow_api.g_varchar2_table(9) := '63686172322831303029203A3D20705F64796E616D69635F616374696F6E2E6174747269627574655F30313B0A202020206C5F7363726F6C6C746F5F737065656420202020202076617263686172322831303029203A3D20705F64796E616D69635F6163';
wwv_flow_api.g_varchar2_table(10) := '74696F6E2E6174747269627574655F30323B0A202020206C5F7363726F6C6C746F5F6475726174696F6E20202076617263686172322831303029203A3D20705F64796E616D69635F616374696F6E2E6174747269627574655F30333B0A202020206C5F73';
wwv_flow_api.g_varchar2_table(11) := '7563636573735F6475726174696F6E2020202076617263686172322831303029203A3D20705F64796E616D69635F616374696F6E2E6174747269627574655F30343B0A202020206C5F6175746F436F6C6C61707365202020202020202076617263686172';
wwv_flow_api.g_varchar2_table(12) := '322831303029203A3D20705F64796E616D69635F616374696F6E2E6174747269627574655F30353B0A0A202020202D2D207661726961626C65730A202020206C5F6475726174696F6E2020202020202020202020206E756D6265723B0A0A626567696E0A';
wwv_flow_api.g_varchar2_table(13) := '202020202D2D2064656275670A20202020617065785F706C7567696E5F7574696C2E64656275675F64796E616D69635F616374696F6E0A20202020202020202820705F706C7567696E2020202020202020203D3E20705F706C7567696E0A202020202020';
wwv_flow_api.g_varchar2_table(14) := '20202C20705F64796E616D69635F616374696F6E203D3E20705F64796E616D69635F616374696F6E0A2020202020202020293B0A0A20202020617065785F6A6176617363726970742E6164645F6C6962726172790A20202020202020202820705F6E616D';
wwv_flow_api.g_varchar2_table(15) := '65202020202020203D3E2027736372697074234D494E23270A20202020202020202C20705F6469726563746F727920203D3E206E766C283A475F415045585F4E4954524F5F554E4956455253414C5F5448454D452C20705F706C7567696E2E66696C655F';
wwv_flow_api.g_varchar2_table(16) := '70726566697829207C7C20276A732F270A2020202020202020293B0A0A202020206966206C5F706572666F726D5F616374696F6E203D20277363726F6C6C746F27207468656E0A20202020202020206C5F6475726174696F6E203A3D2063617365207768';
wwv_flow_api.g_varchar2_table(17) := '656E206C5F7363726F6C6C746F5F737065656420213D2027637573746F6D27200A2020202020202020202020202020202020202020202020207468656E20705F64796E616D69635F616374696F6E2E6174747269627574655F3032200A20202020202020';
wwv_flow_api.g_varchar2_table(18) := '2020202020202020202020202020202020656C736520705F64796E616D69635F616374696F6E2E6174747269627574655F3033200A20202020202020202020202020202020202020202020656E643B0A20202020656C736966206C5F706572666F726D5F';
wwv_flow_api.g_varchar2_table(19) := '616374696F6E203D2027636F6E666967757265737563636573736E6F7469666475726174696F6E27207468656E0A20202020202020206C5F6475726174696F6E203A3D206C5F737563636573735F6475726174696F6E3B0A20202020656E642069663B0A';
wwv_flow_api.g_varchar2_table(20) := '0A202020206C5F726573756C742E6A6176617363726970745F66756E6374696F6E203A3D2027617065785574696C732E756E6976657273616C5468656D652E65786563273B0A202020206C5F726573756C742E6174747269627574655F30312020202020';
wwv_flow_api.g_varchar2_table(21) := '2020203A3D206C5F706572666F726D5F616374696F6E3B0A202020200A202020202D2D466F7220616374696F6E20225363726F6C6C20546F22206F722022436F6E6669677572652053756363657373204E6F74696669636174696F6E204475726174696F';
wwv_flow_api.g_varchar2_table(22) := '6E220A202020206C5F726573756C742E6174747269627574655F303220202020202020203A3D206C5F6475726174696F6E3B0A202020200A202020202D2D206175746F436F6C6C6170736520592F4E0A202020206C5F726573756C742E61747472696275';
wwv_flow_api.g_varchar2_table(23) := '74655F303320202020202020203A3D206C5F6175746F436F6C6C617073653B0A0A2020202072657475726E206C5F726573756C743B0A0A656E642072656E6465723B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(27602732819714370)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_file_name=>'plsql/render.sql'
,p_mime_type=>'application/octet-stream'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '77696E646F772E617065785574696C73203D2077696E646F772E617065785574696C73207C7C207B7D3B0A77696E646F772E617065785574696C732E756E6976657273616C5468656D65203D207B0A09636F6C6C617073654E61764D656E753A2066756E';
wwv_flow_api.g_varchar2_table(2) := '6374696F6E28297B0A09092F2A2074686520746F67676C6557696467657473206F626A656374206973206E6F74206578706F73656420696E2031392E3120616E796D6F72650A0909202A20617065782E7468656D6534322E746F67676C65576964676574';
wwv_flow_api.g_varchar2_table(3) := '732E636F6C6C6170736557696467657428276E617627293B0A0909202A206D617962652074686579206272696E67206974206261636B20617420736F6D6520706F696E742E0A0909202A205573696E67206120776F726B61726F756E6420696E73746561';
wwv_flow_api.g_varchar2_table(4) := '640A0909202A2F0A092020202069662824282723745F427574746F6E5F6E6176436F6E74726F6C27292E686173436C617373282769732D6163746976652729297B0A09092020202024282723745F427574746F6E5F6E6176436F6E74726F6C27292E636C';
wwv_flow_api.g_varchar2_table(5) := '69636B28292E626C757228293B0A09202020207D0A097D2C0A09657870616E644E61764D656E753A2066756E6374696F6E28297B0A09092F2A2074686520746F67676C6557696467657473206F626A656374206973206E6F74206578706F73656420696E';
wwv_flow_api.g_varchar2_table(6) := '2031392E3120616E796D6F72650A0909202A20617065782E7468656D6534322E746F67676C65576964676574732E657870616E6457696467657428276E617627293B0A0909202A206D617962652074686579206272696E67206974206261636B20617420';
wwv_flow_api.g_varchar2_table(7) := '736F6D6520706F696E742E0A0909202A205573696E67206120776F726B61726F756E6420696E73746561640A0909202A2F0A09202020206966282124282723745F427574746F6E5F6E6176436F6E74726F6C27292E686173436C617373282769732D6163';
wwv_flow_api.g_varchar2_table(8) := '746976652729297B0A09092020202024282723745F427574746F6E5F6E6176436F6E74726F6C27292E636C69636B28292E626C757228293B0A09202020207D0A097D2C0A097365744E61764D656E754E6F6465734175746F436F6C6C617073653A206675';
wwv_flow_api.g_varchar2_table(9) := '6E6374696F6E286F6E297B0A090924282723745F547265654E617627292E747265655669657728226F7074696F6E222C20226175746F436F6C6C61707365222C206F6E293B0A097D2C0A09636F6C6C617073654E61764D656E754E6F6465733A2066756E';
wwv_flow_api.g_varchar2_table(10) := '6374696F6E28297B0A090924282723745F547265654E617627292E74726565566965772827636F6C6C61707365416C6C27293B0A097D2C0A09657870616E644E61764D656E754E6F6465733A2066756E6374696F6E28297B0A090924282723745F547265';
wwv_flow_api.g_varchar2_table(11) := '654E617627292E74726565566965772827657870616E64416C6C27293B0A097D2C0A09636F6C6C61707365436F6C6C61707369626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72297B0A09097661722024726567696F6E203D202428';
wwv_flow_api.g_varchar2_table(12) := '73656C6563746F72293B0A09092F2F20536565207769646765742E546F67676C65436F72652E6A7320616E64207769646765742E636F6C6C61707369626C652E6A730A09092F2F205468697320756E666F7274756E6174656C792072656D61696E732074';
wwv_flow_api.g_varchar2_table(13) := '68652062657374206F7074696F6E0A09092F2F6966202824726567696F6E2E686173436C617373282769732D657870616E646564272929207B0A09092F2F0924726567696F6E2E66696E642827627574746F6E2E742D427574746F6E2D2D686964655368';
wwv_flow_api.g_varchar2_table(14) := '6F7727292E666972737428292E636C69636B28292E626C757228293B0A09092F2F7D0A090969662824726567696F6E2E636F6C6C61707369626C6528292E6C656E6774683D3D30297B0A090909617065782E64656275672E6572726F722827526567696F';
wwv_flow_api.g_varchar2_table(15) := '6E206973206E6F7420636F6C6C61707369626C6527293B0A09090972657475726E3B0A09097D0A090924726567696F6E2E636F6C6C61707369626C652827696E7374616E636527292E636F72652E636F6C6C6170736528293B0A090924726567696F6E2E';
wwv_flow_api.g_varchar2_table(16) := '636F6C6C61707369626C652827696E7374616E636527292E636F72652E73657455736572507265666572656E63652866616C7365293B0A097D2C0A09657870616E64436F6C6C61707369626C65526567696F6E3A2066756E6374696F6E2873656C656374';
wwv_flow_api.g_varchar2_table(17) := '6F72297B0A09097661722024726567696F6E203D20242873656C6563746F72293B0A090969662824726567696F6E2E636F6C6C61707369626C6528292E6C656E6774683D3D30297B0A090909617065782E64656275672E6572726F722827526567696F6E';
wwv_flow_api.g_varchar2_table(18) := '206973206E6F7420636F6C6C61707369626C6527293B0A09090972657475726E3B0A09097D0A090924726567696F6E2E636F6C6C61707369626C652827696E7374616E636527292E636F72652E657870616E6428293B0A090924726567696F6E2E636F6C';
wwv_flow_api.g_varchar2_table(19) := '6C61707369626C652827696E7374616E636527292E636F72652E73657455736572507265666572656E63652874727565293B0A097D2C0A096D6178696D697A654D6178696D697A61626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72';
wwv_flow_api.g_varchar2_table(20) := '297B0A0909766172202462746E203D202428272E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E20627574746F6E272C2073656C6563746F72292E666972737428293B0A09096966282462746E2E617474722827617269612D6578';
wwv_flow_api.g_varchar2_table(21) := '70616E6465642729203D3D202766616C736527297B0A0909092462746E2E636C69636B28292E626C757228293B0A09097D0A097D2C0A09726573746F72654D6178696D697A61626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72297B';
wwv_flow_api.g_varchar2_table(22) := '0A0909766172202462746E203D202428272E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E20627574746F6E272C2073656C6563746F72292E666972737428293B0A09096966282462746E2E617474722827617269612D65787061';
wwv_flow_api.g_varchar2_table(23) := '6E6465642729203D3D20277472756527297B0A0909092462746E2E636C69636B28292E626C757228293B0A09097D0A097D2C0A09636F6E666967757265537563636573734E6F74696669636174696F6E4475726174696F6E3A2066756E6374696F6E2864';
wwv_flow_api.g_varchar2_table(24) := '75726174696F6E297B0A09092F2F3E3D31392E310A0909696628617065782E7468656D6534322E7574696C2E636F6E666967415045584D736773297B0A090909617065782E7468656D6534322E7574696C2E636F6E666967415045584D736773287B0A09';
wwv_flow_api.g_varchar2_table(25) := '0920202020096175746F4469736D6973733A20747275652C0A090920202020096475726174696F6E3A207061727365496E74286475726174696F6E290A09092020097D293B0A09092F2F3C31392E310A09097D20656C7365207B0A090909617065782E6D';
wwv_flow_api.g_varchar2_table(26) := '6573736167652E7365745468656D65486F6F6B73287B0A090909096265666F726553686F773A2066756E6374696F6E28704D7367547970652C2070456C656D656E7424297B0A090909090969662028704D7367547970653D3D277375636365737327297B';
wwv_flow_api.g_varchar2_table(27) := '200A09090909090973657454696D656F75742866756E6374696F6E28297B0A090909090909092428272E742D416C65727427292E666164654F75742827736C6F7727293B0A0909090909097D2C207061727365496E74286475726174696F6E29293B0A09';
wwv_flow_api.g_varchar2_table(28) := '090909097D0A090909097D0A0909097D293B0A09097D0A097D2C0A097363726F6C6C546F3A2066756E6374696F6E2873656C6563746F722C206475726174696F6E297B0A09092F2F617065782E7468656D6534322E7574696C2E7363726F6C6C546F2869';
wwv_flow_api.g_varchar2_table(29) := '64293B0A09092F2F6368616E676564207468652064656661756C74207363726F6C6C546F2066756E6374696F6E20746F206E6F74206F6E6C792068616E646C652069642D732C0A09092F2F62757420616E79206A51756572792073656C6563746F72206F';
wwv_flow_api.g_varchar2_table(30) := '72206A5175657279206F626A6563740A202020202020202076617220656C656D242C0A202020202020202020202020656C656D4F66667365743B0A0A2020202020202020696628747970656F66286475726174696F6E2920213D20226E756D6265722229';
wwv_flow_api.g_varchar2_table(31) := '7B0A2020202020202020096475726174696F6E203D203430303B0A20202020202020207D0A0A2020202020202020656C656D24203D2024282073656C6563746F7220293B0A20202020202020206966202820656C656D245B305D2029207B0A2020202020';
wwv_flow_api.g_varchar2_table(32) := '20202020202020656C656D4F6666736574203D20656C656D242E6F666673657428292E746F70202D20617065782E7468656D652E64656661756C74537469636B79546F7028293B0A2020202020202020202020202428202768746D6C2C20626F6479272C';
wwv_flow_api.g_varchar2_table(33) := '20617065782E6750616765436F6E746578742420292E616E696D617465287B0A202020202020202020202020202020207363726F6C6C546F703A20656C656D4F66667365740A2020202020202020202020207D2C206475726174696F6E293B0A20202020';
wwv_flow_api.g_varchar2_table(34) := '202020207D0A097D2C0A09657865633A2066756E6374696F6E28297B0A09097661722064615468697320090920203D20746869733B0A090976617220706572666F726D416374696F6E203D206461546869732E616374696F6E2E61747472696275746530';
wwv_flow_api.g_varchar2_table(35) := '313B0A0909766172206475726174696F6E200920203D206461546869732E616374696F6E2E61747472696275746530323B0A0A090973776974636828706572666F726D416374696F6E297B0A090909636173652027636F6C6C617073656E61766D656E75';
wwv_flow_api.g_varchar2_table(36) := '273A0A09090909617065785574696C732E756E6976657273616C5468656D652E636F6C6C617073654E61764D656E7528293B0A09090909627265616B3B0A090909636173652027657870616E646E61766D656E75273A0A09090909617065785574696C73';
wwv_flow_api.g_varchar2_table(37) := '2E756E6976657273616C5468656D652E657870616E644E61764D656E7528293B0A09090909627265616B3B0A090909636173652027636F6C6C617073656E61766D656E756E6F646573273A0A09090909617065785574696C732E756E6976657273616C54';
wwv_flow_api.g_varchar2_table(38) := '68656D652E636F6C6C617073654E61764D656E754E6F64657328293B0A09090909627265616B3B0A090909636173652027657870616E646E61766D656E756E6F646573273A0A09090909617065785574696C732E756E6976657273616C5468656D652E65';
wwv_flow_api.g_varchar2_table(39) := '7870616E644E61764D656E754E6F64657328293B0A09090909627265616B3B0A0909096361736520277365746E61766D656E756E6F6465736175746F636F6C6C61707365273A0A09090909617065785574696C732E756E6976657273616C5468656D652E';
wwv_flow_api.g_varchar2_table(40) := '7365744E61764D656E754E6F6465734175746F436F6C6C61707365286461546869732E616374696F6E2E6174747269627574653033203D3D20275927293B0A09090909627265616B3B0A090909636173652027636F6C6C61707365636F6C6C6170736962';
wwv_flow_api.g_varchar2_table(41) := '6C65726567696F6E273A0A090909096966286461546869732E616374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B0A0909090909617065782E64656275672E6572726F7228274120726567696F6E206E';
wwv_flow_api.g_varchar2_table(42) := '6565647320746F2062652073656C656374656420666F722027202B206461546869732E616374696F6E2E616374696F6E293B0A090909097D20656C7365207B0A0909090909617065785574696C732E756E6976657273616C5468656D652E636F6C6C6170';
wwv_flow_api.g_varchar2_table(43) := '7365436F6C6C61707369626C65526567696F6E286461546869732E6166666563746564456C656D656E7473293B0A090909097D0A09090909627265616B3B0A090909636173652027657870616E64636F6C6C61707369626C65726567696F6E273A0A0909';
wwv_flow_api.g_varchar2_table(44) := '09096966286461546869732E616374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B0A0909090909617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F206265207365';
wwv_flow_api.g_varchar2_table(45) := '6C656374656420666F722027202B206461546869732E616374696F6E2E616374696F6E293B0A090909097D20656C7365207B0A0909090909617065785574696C732E756E6976657273616C5468656D652E657870616E64436F6C6C61707369626C655265';
wwv_flow_api.g_varchar2_table(46) := '67696F6E286461546869732E6166666563746564456C656D656E7473293B0A090909097D0A09090909627265616B3B0A0909096361736520276D6178696D697A61626C65726567696F6E6D6178696D697A65273A0A090909096966286461546869732E61';
wwv_flow_api.g_varchar2_table(47) := '6374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B0A0909090909617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F2062652073656C656374656420666F72202720';
wwv_flow_api.g_varchar2_table(48) := '2B206461546869732E616374696F6E2E616374696F6E293B0A090909097D20656C7365207B0A0909090909617065785574696C732E756E6976657273616C5468656D652E6D6178696D697A654D6178696D697A61626C65526567696F6E28646154686973';
wwv_flow_api.g_varchar2_table(49) := '2E6166666563746564456C656D656E7473293B0A090909097D0A09090909627265616B3B0A0909096361736520276D6178696D697A61626C65726567696F6E726573746F7265273A0A090909096966286461546869732E616374696F6E2E616666656374';
wwv_flow_api.g_varchar2_table(50) := '6564456C656D656E74735479706520213D2027524547494F4E27297B0A0909090909617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F2062652073656C656374656420666F722027202B206461546869732E616374';
wwv_flow_api.g_varchar2_table(51) := '696F6E2E616374696F6E293B0A090909097D20656C7365207B0A0909090909617065785574696C732E756E6976657273616C5468656D652E726573746F72654D6178696D697A61626C65526567696F6E286461546869732E6166666563746564456C656D';
wwv_flow_api.g_varchar2_table(52) := '656E7473293B0A090909097D0A09090909627265616B3B0A0909096361736520277363726F6C6C746F273A0A090909092F2F6966206E6F20416666656374656420456C656D656E74207761732073656C65637465642C206461546869732E616666656374';
wwv_flow_api.g_varchar2_table(53) := '6564456C656D656E74732077696C6C2028666F7220736F6D6520726561736F6E292062652074686520646F63756D656E74206F626A6563740A090909092F2F736F20776520636865636B20746865206166666563746564456C656D656E74735479706520';
wwv_flow_api.g_varchar2_table(54) := '77686963682077696C6C206265206E756C6C0A090909092F2F6461546869732E6166666563746564456C656D656E74732E6C656E6774682077696C6C2062652030206966207468652070726F76696465642073656C6563746F722072657475726E73206E';
wwv_flow_api.g_varchar2_table(55) := '6F206F626A656374730A09090909696628216461546869732E616374696F6E2E6166666563746564456C656D656E747354797065207C7C206461546869732E6166666563746564456C656D656E74732E6C656E677468203D3D2030297B0A090909090961';
wwv_flow_api.g_varchar2_table(56) := '7065782E64656275672E6572726F7228274E6F20416666656374656420456C656D656E7420666F756E6420666F722027202B206461546869732E616374696F6E2E616374696F6E293B0A090909097D20656C7365207B0A0909090909617065785574696C';
wwv_flow_api.g_varchar2_table(57) := '732E756E6976657273616C5468656D652E7363726F6C6C546F286461546869732E6166666563746564456C656D656E74732E65712830292C207061727365496E74286475726174696F6E29293B0A090909097D0A09090909627265616B3B0A0909096361';
wwv_flow_api.g_varchar2_table(58) := '73652027636F6E666967757265737563636573736E6F74696669636174696F6E6475726174696F6E273A0A09090909617065785574696C732E756E6976657273616C5468656D652E636F6E666967757265537563636573734E6F74696669636174696F6E';
wwv_flow_api.g_varchar2_table(59) := '4475726174696F6E287061727365496E74286475726174696F6E29293B0A09090909627265616B3B0A09090964656661756C743A0A09090909617065782E64656275672E6572726F722827416374696F6E202227202B20706572666F726D416374696F6E';
wwv_flow_api.g_varchar2_table(60) := '202B20272220666F722027202B206461546869732E616374696F6E2E616374696F6E202B2027206E6F742068616E646C656427293B0A09097D0A097D0A7D3B0A0A617065782E6A51756572792877696E646F77292E6F6E28276170657877696E646F7772';
wwv_flow_api.g_varchar2_table(61) := '6573697A6564272C2066756E6374696F6E2829207B0A09242827626F647927292E74726967676572282761752D75742D6170657877696E646F77726573697A656427293B0A7D293B0A0A617065782E6A51756572792877696E646F77292E6F6E28277468';
wwv_flow_api.g_varchar2_table(62) := '656D6534327265616479272C2066756E6374696F6E2829207B0A09242827626F647927292E74726967676572282761752D75742D7468656D653432726561647927293B0A7D293B0A0A617065782E6A5175657279282723745F547265654E617627292E6F';
wwv_flow_api.g_varchar2_table(63) := '6E28277468656D6534326C61796F75746368616E676564272C2066756E6374696F6E286576656E742C206F626A29207B0A096966286F626A2E616374696F6E203D3D2027657870616E6427297B0A0909242827626F647927292E74726967676572282761';
wwv_flow_api.g_varchar2_table(64) := '752D75742D7468656D6534326E61766D656E75657870616E64656427293B0A097D20656C736520696620286F626A2E616374696F6E203D3D2027636F6C6C6170736527297B0A0909242827626F647927292E74726967676572282761752D75742D746865';
wwv_flow_api.g_varchar2_table(65) := '6D6534326E61766D656E75636F6C6C617073656427293B0A097D0A7D293B0A0A2F2F2320736F757263654D617070696E6755524C3D7363726970742E6A732E6D61700A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(54920908099087713)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_file_name=>'js/script.js'
,p_mime_type=>'application/x-javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '77696E646F772E617065785574696C733D77696E646F772E617065785574696C737C7C7B7D2C77696E646F772E617065785574696C732E756E6976657273616C5468656D653D7B636F6C6C617073654E61764D656E753A66756E6374696F6E28297B2428';
wwv_flow_api.g_varchar2_table(2) := '2223745F427574746F6E5F6E6176436F6E74726F6C22292E686173436C617373282269732D6163746976652229262624282223745F427574746F6E5F6E6176436F6E74726F6C22292E636C69636B28292E626C757228297D2C657870616E644E61764D65';
wwv_flow_api.g_varchar2_table(3) := '6E753A66756E6374696F6E28297B24282223745F427574746F6E5F6E6176436F6E74726F6C22292E686173436C617373282269732D61637469766522297C7C24282223745F427574746F6E5F6E6176436F6E74726F6C22292E636C69636B28292E626C75';
wwv_flow_api.g_varchar2_table(4) := '7228297D2C7365744E61764D656E754E6F6465734175746F436F6C6C617073653A66756E6374696F6E2865297B24282223745F547265654E617622292E747265655669657728226F7074696F6E222C226175746F436F6C6C61707365222C65297D2C636F';
wwv_flow_api.g_varchar2_table(5) := '6C6C617073654E61764D656E754E6F6465733A66756E6374696F6E28297B24282223745F547265654E617622292E74726565566965772822636F6C6C61707365416C6C22297D2C657870616E644E61764D656E754E6F6465733A66756E6374696F6E2829';
wwv_flow_api.g_varchar2_table(6) := '7B24282223745F547265654E617622292E74726565566965772822657870616E64416C6C22297D2C636F6C6C61707365436F6C6C61707369626C65526567696F6E3A66756E6374696F6E2865297B76617220613D242865293B30213D612E636F6C6C6170';
wwv_flow_api.g_varchar2_table(7) := '7369626C6528292E6C656E6774683F28612E636F6C6C61707369626C652822696E7374616E636522292E636F72652E636F6C6C6170736528292C612E636F6C6C61707369626C652822696E7374616E636522292E636F72652E7365745573657250726566';
wwv_flow_api.g_varchar2_table(8) := '6572656E636528213129293A617065782E64656275672E6572726F722822526567696F6E206973206E6F7420636F6C6C61707369626C6522297D2C657870616E64436F6C6C61707369626C65526567696F6E3A66756E6374696F6E2865297B7661722061';
wwv_flow_api.g_varchar2_table(9) := '3D242865293B30213D612E636F6C6C61707369626C6528292E6C656E6774683F28612E636F6C6C61707369626C652822696E7374616E636522292E636F72652E657870616E6428292C612E636F6C6C61707369626C652822696E7374616E636522292E63';
wwv_flow_api.g_varchar2_table(10) := '6F72652E73657455736572507265666572656E636528213029293A617065782E64656275672E6572726F722822526567696F6E206973206E6F7420636F6C6C61707369626C6522297D2C6D6178696D697A654D6178696D697A61626C65526567696F6E3A';
wwv_flow_api.g_varchar2_table(11) := '66756E6374696F6E2865297B76617220613D2428222E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E20627574746F6E222C65292E666972737428293B2266616C7365223D3D612E617474722822617269612D657870616E646564';
wwv_flow_api.g_varchar2_table(12) := '22292626612E636C69636B28292E626C757228297D2C726573746F72654D6178696D697A61626C65526567696F6E3A66756E6374696F6E2865297B76617220613D2428222E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E206275';
wwv_flow_api.g_varchar2_table(13) := '74746F6E222C65292E666972737428293B2274727565223D3D612E617474722822617269612D657870616E64656422292626612E636C69636B28292E626C757228297D2C636F6E666967757265537563636573734E6F74696669636174696F6E44757261';
wwv_flow_api.g_varchar2_table(14) := '74696F6E3A66756E6374696F6E2865297B617065782E7468656D6534322E7574696C2E636F6E666967415045584D7367733F617065782E7468656D6534322E7574696C2E636F6E666967415045584D736773287B6175746F4469736D6973733A21302C64';
wwv_flow_api.g_varchar2_table(15) := '75726174696F6E3A7061727365496E742865297D293A617065782E6D6573736167652E7365745468656D65486F6F6B73287B6265666F726553686F773A66756E6374696F6E28612C74297B2273756363657373223D3D61262673657454696D656F757428';
wwv_flow_api.g_varchar2_table(16) := '66756E6374696F6E28297B2428222E742D416C65727422292E666164654F75742822736C6F7722297D2C7061727365496E74286529297D7D297D2C7363726F6C6C546F3A66756E6374696F6E28652C61297B76617220742C6E3B226E756D62657222213D';
wwv_flow_api.g_varchar2_table(17) := '747970656F662061262628613D343030292C28743D24286529295B305D2626286E3D742E6F666673657428292E746F702D617065782E7468656D652E64656661756C74537469636B79546F7028292C24282268746D6C2C20626F6479222C617065782E67';
wwv_flow_api.g_varchar2_table(18) := '50616765436F6E7465787424292E616E696D617465287B7363726F6C6C546F703A6E7D2C6129297D2C657865633A66756E6374696F6E28297B76617220653D746869732E616374696F6E2E61747472696275746530312C613D746869732E616374696F6E';
wwv_flow_api.g_varchar2_table(19) := '2E61747472696275746530323B7377697463682865297B6361736522636F6C6C617073656E61766D656E75223A617065785574696C732E756E6976657273616C5468656D652E636F6C6C617073654E61764D656E7528293B627265616B3B636173652265';
wwv_flow_api.g_varchar2_table(20) := '7870616E646E61766D656E75223A617065785574696C732E756E6976657273616C5468656D652E657870616E644E61764D656E7528293B627265616B3B6361736522636F6C6C617073656E61766D656E756E6F646573223A617065785574696C732E756E';
wwv_flow_api.g_varchar2_table(21) := '6976657273616C5468656D652E636F6C6C617073654E61764D656E754E6F64657328293B627265616B3B6361736522657870616E646E61766D656E756E6F646573223A617065785574696C732E756E6976657273616C5468656D652E657870616E644E61';
wwv_flow_api.g_varchar2_table(22) := '764D656E754E6F64657328293B627265616B3B63617365227365746E61766D656E756E6F6465736175746F636F6C6C61707365223A617065785574696C732E756E6976657273616C5468656D652E7365744E61764D656E754E6F6465734175746F436F6C';
wwv_flow_api.g_varchar2_table(23) := '6C61707365282259223D3D746869732E616374696F6E2E6174747269627574653033293B627265616B3B6361736522636F6C6C61707365636F6C6C61707369626C65726567696F6E223A22524547494F4E22213D746869732E616374696F6E2E61666665';
wwv_flow_api.g_varchar2_table(24) := '63746564456C656D656E7473547970653F617065782E64656275672E6572726F7228224120726567696F6E206E6565647320746F2062652073656C656374656420666F7220222B746869732E616374696F6E2E616374696F6E293A617065785574696C73';
wwv_flow_api.g_varchar2_table(25) := '2E756E6976657273616C5468656D652E636F6C6C61707365436F6C6C61707369626C65526567696F6E28746869732E6166666563746564456C656D656E7473293B627265616B3B6361736522657870616E64636F6C6C61707369626C65726567696F6E22';
wwv_flow_api.g_varchar2_table(26) := '3A22524547494F4E22213D746869732E616374696F6E2E6166666563746564456C656D656E7473547970653F617065782E64656275672E6572726F7228224120726567696F6E206E6565647320746F2062652073656C656374656420666F7220222B7468';
wwv_flow_api.g_varchar2_table(27) := '69732E616374696F6E2E616374696F6E293A617065785574696C732E756E6976657273616C5468656D652E657870616E64436F6C6C61707369626C65526567696F6E28746869732E6166666563746564456C656D656E7473293B627265616B3B63617365';
wwv_flow_api.g_varchar2_table(28) := '226D6178696D697A61626C65726567696F6E6D6178696D697A65223A22524547494F4E22213D746869732E616374696F6E2E6166666563746564456C656D656E7473547970653F617065782E64656275672E6572726F7228224120726567696F6E206E65';
wwv_flow_api.g_varchar2_table(29) := '65647320746F2062652073656C656374656420666F7220222B746869732E616374696F6E2E616374696F6E293A617065785574696C732E756E6976657273616C5468656D652E6D6178696D697A654D6178696D697A61626C65526567696F6E2874686973';
wwv_flow_api.g_varchar2_table(30) := '2E6166666563746564456C656D656E7473293B627265616B3B63617365226D6178696D697A61626C65726567696F6E726573746F7265223A22524547494F4E22213D746869732E616374696F6E2E6166666563746564456C656D656E7473547970653F61';
wwv_flow_api.g_varchar2_table(31) := '7065782E64656275672E6572726F7228224120726567696F6E206E6565647320746F2062652073656C656374656420666F7220222B746869732E616374696F6E2E616374696F6E293A617065785574696C732E756E6976657273616C5468656D652E7265';
wwv_flow_api.g_varchar2_table(32) := '73746F72654D6178696D697A61626C65526567696F6E28746869732E6166666563746564456C656D656E7473293B627265616B3B63617365227363726F6C6C746F223A746869732E616374696F6E2E6166666563746564456C656D656E74735479706526';
wwv_flow_api.g_varchar2_table(33) := '2630213D746869732E6166666563746564456C656D656E74732E6C656E6774683F617065785574696C732E756E6976657273616C5468656D652E7363726F6C6C546F28746869732E6166666563746564456C656D656E74732E65712830292C7061727365';
wwv_flow_api.g_varchar2_table(34) := '496E74286129293A617065782E64656275672E6572726F7228224E6F20416666656374656420456C656D656E7420666F756E6420666F7220222B746869732E616374696F6E2E616374696F6E293B627265616B3B6361736522636F6E6669677572657375';
wwv_flow_api.g_varchar2_table(35) := '63636573736E6F74696669636174696F6E6475726174696F6E223A617065785574696C732E756E6976657273616C5468656D652E636F6E666967757265537563636573734E6F74696669636174696F6E4475726174696F6E287061727365496E74286129';
wwv_flow_api.g_varchar2_table(36) := '293B627265616B3B64656661756C743A617065782E64656275672E6572726F722827416374696F6E2022272B652B272220666F7220272B746869732E616374696F6E2E616374696F6E2B22206E6F742068616E646C656422297D7D7D2C617065782E6A51';
wwv_flow_api.g_varchar2_table(37) := '756572792877696E646F77292E6F6E28226170657877696E646F77726573697A6564222C66756E6374696F6E28297B242822626F647922292E74726967676572282261752D75742D6170657877696E646F77726573697A656422297D292C617065782E6A';
wwv_flow_api.g_varchar2_table(38) := '51756572792877696E646F77292E6F6E28227468656D6534327265616479222C66756E6374696F6E28297B242822626F647922292E74726967676572282261752D75742D7468656D653432726561647922297D292C617065782E6A517565727928222374';
wwv_flow_api.g_varchar2_table(39) := '5F547265654E617622292E6F6E28227468656D6534326C61796F75746368616E676564222C66756E6374696F6E28652C61297B22657870616E64223D3D612E616374696F6E3F242822626F647922292E74726967676572282261752D75742D7468656D65';
wwv_flow_api.g_varchar2_table(40) := '34326E61766D656E75657870616E64656422293A22636F6C6C61707365223D3D612E616374696F6E2626242822626F647922292E74726967676572282261752D75742D7468656D6534326E61766D656E75636F6C6C617073656422297D293B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(54931926202674833)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_file_name=>'js/script.min.js'
,p_mime_type=>'application/x-javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '7B2276657273696F6E223A332C226E616D6573223A5B5D2C226D617070696E6773223A22222C22736F7572636573223A5B227363726970742E6A73225D2C22736F7572636573436F6E74656E74223A5B2277696E646F772E617065785574696C73203D20';
wwv_flow_api.g_varchar2_table(2) := '77696E646F772E617065785574696C73207C7C207B7D3B5C6E77696E646F772E617065785574696C732E756E6976657273616C5468656D65203D207B5C6E5C74636F6C6C617073654E61764D656E753A2066756E6374696F6E28297B5C6E5C745C742F2A';
wwv_flow_api.g_varchar2_table(3) := '2074686520746F67676C6557696467657473206F626A656374206973206E6F74206578706F73656420696E2031392E3120616E796D6F72655C6E5C745C74202A20617065782E7468656D6534322E746F67676C65576964676574732E636F6C6C61707365';
wwv_flow_api.g_varchar2_table(4) := '57696467657428276E617627293B5C6E5C745C74202A206D617962652074686579206272696E67206974206261636B20617420736F6D6520706F696E742E5C6E5C745C74202A205573696E67206120776F726B61726F756E6420696E73746561645C6E5C';
wwv_flow_api.g_varchar2_table(5) := '745C74202A2F5C6E5C742020202069662824282723745F427574746F6E5F6E6176436F6E74726F6C27292E686173436C617373282769732D6163746976652729297B5C6E5C745C742020202024282723745F427574746F6E5F6E6176436F6E74726F6C27';
wwv_flow_api.g_varchar2_table(6) := '292E636C69636B28292E626C757228293B5C6E5C74202020207D5C6E5C747D2C5C6E5C74657870616E644E61764D656E753A2066756E6374696F6E28297B5C6E5C745C742F2A2074686520746F67676C6557696467657473206F626A656374206973206E';
wwv_flow_api.g_varchar2_table(7) := '6F74206578706F73656420696E2031392E3120616E796D6F72655C6E5C745C74202A20617065782E7468656D6534322E746F67676C65576964676574732E657870616E6457696467657428276E617627293B5C6E5C745C74202A206D6179626520746865';
wwv_flow_api.g_varchar2_table(8) := '79206272696E67206974206261636B20617420736F6D6520706F696E742E5C6E5C745C74202A205573696E67206120776F726B61726F756E6420696E73746561645C6E5C745C74202A2F5C6E5C74202020206966282124282723745F427574746F6E5F6E';
wwv_flow_api.g_varchar2_table(9) := '6176436F6E74726F6C27292E686173436C617373282769732D6163746976652729297B5C6E5C745C742020202024282723745F427574746F6E5F6E6176436F6E74726F6C27292E636C69636B28292E626C757228293B5C6E5C74202020207D5C6E5C747D';
wwv_flow_api.g_varchar2_table(10) := '2C5C6E5C747365744E61764D656E754E6F6465734175746F436F6C6C617073653A2066756E6374696F6E286F6E297B5C6E5C745C7424282723745F547265654E617627292E7472656556696577285C226F7074696F6E5C222C205C226175746F436F6C6C';
wwv_flow_api.g_varchar2_table(11) := '617073655C222C206F6E293B5C6E5C747D2C5C6E5C74636F6C6C617073654E61764D656E754E6F6465733A2066756E6374696F6E28297B5C6E5C745C7424282723745F547265654E617627292E74726565566965772827636F6C6C61707365416C6C2729';
wwv_flow_api.g_varchar2_table(12) := '3B5C6E5C747D2C5C6E5C74657870616E644E61764D656E754E6F6465733A2066756E6374696F6E28297B5C6E5C745C7424282723745F547265654E617627292E74726565566965772827657870616E64416C6C27293B5C6E5C747D2C5C6E5C74636F6C6C';
wwv_flow_api.g_varchar2_table(13) := '61707365436F6C6C61707369626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72297B5C6E5C745C747661722024726567696F6E203D20242873656C6563746F72293B5C6E5C745C742F2F20536565207769646765742E546F67676C65';
wwv_flow_api.g_varchar2_table(14) := '436F72652E6A7320616E64207769646765742E636F6C6C61707369626C652E6A735C6E5C745C742F2F205468697320756E666F7274756E6174656C792072656D61696E73207468652062657374206F7074696F6E5C6E5C745C742F2F6966202824726567';
wwv_flow_api.g_varchar2_table(15) := '696F6E2E686173436C617373282769732D657870616E646564272929207B5C6E5C745C742F2F5C7424726567696F6E2E66696E642827627574746F6E2E742D427574746F6E2D2D6869646553686F7727292E666972737428292E636C69636B28292E626C';
wwv_flow_api.g_varchar2_table(16) := '757228293B5C6E5C745C742F2F7D5C6E5C745C7469662824726567696F6E2E636F6C6C61707369626C6528292E6C656E6774683D3D30297B5C6E5C745C745C74617065782E64656275672E6572726F722827526567696F6E206973206E6F7420636F6C6C';
wwv_flow_api.g_varchar2_table(17) := '61707369626C6527293B5C6E5C745C745C7472657475726E3B5C6E5C745C747D5C6E5C745C7424726567696F6E2E636F6C6C61707369626C652827696E7374616E636527292E636F72652E636F6C6C6170736528293B5C6E5C745C7424726567696F6E2E';
wwv_flow_api.g_varchar2_table(18) := '636F6C6C61707369626C652827696E7374616E636527292E636F72652E73657455736572507265666572656E63652866616C7365293B5C6E5C747D2C5C6E5C74657870616E64436F6C6C61707369626C65526567696F6E3A2066756E6374696F6E287365';
wwv_flow_api.g_varchar2_table(19) := '6C6563746F72297B5C6E5C745C747661722024726567696F6E203D20242873656C6563746F72293B5C6E5C745C7469662824726567696F6E2E636F6C6C61707369626C6528292E6C656E6774683D3D30297B5C6E5C745C745C74617065782E6465627567';
wwv_flow_api.g_varchar2_table(20) := '2E6572726F722827526567696F6E206973206E6F7420636F6C6C61707369626C6527293B5C6E5C745C745C7472657475726E3B5C6E5C745C747D5C6E5C745C7424726567696F6E2E636F6C6C61707369626C652827696E7374616E636527292E636F7265';
wwv_flow_api.g_varchar2_table(21) := '2E657870616E6428293B5C6E5C745C7424726567696F6E2E636F6C6C61707369626C652827696E7374616E636527292E636F72652E73657455736572507265666572656E63652874727565293B5C6E5C747D2C5C6E5C746D6178696D697A654D6178696D';
wwv_flow_api.g_varchar2_table(22) := '697A61626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72297B5C6E5C745C74766172202462746E203D202428272E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E20627574746F6E272C2073656C6563746F72';
wwv_flow_api.g_varchar2_table(23) := '292E666972737428293B5C6E5C745C746966282462746E2E617474722827617269612D657870616E6465642729203D3D202766616C736527297B5C6E5C745C745C742462746E2E636C69636B28292E626C757228293B5C6E5C745C747D5C6E5C747D2C5C';
wwv_flow_api.g_varchar2_table(24) := '6E5C74726573746F72654D6178696D697A61626C65526567696F6E3A2066756E6374696F6E2873656C6563746F72297B5C6E5C745C74766172202462746E203D202428272E6A732D6D6178696D697A65427574746F6E436F6E7461696E6572203E206275';
wwv_flow_api.g_varchar2_table(25) := '74746F6E272C2073656C6563746F72292E666972737428293B5C6E5C745C746966282462746E2E617474722827617269612D657870616E6465642729203D3D20277472756527297B5C6E5C745C745C742462746E2E636C69636B28292E626C757228293B';
wwv_flow_api.g_varchar2_table(26) := '5C6E5C745C747D5C6E5C747D2C5C6E5C74636F6E666967757265537563636573734E6F74696669636174696F6E4475726174696F6E3A2066756E6374696F6E286475726174696F6E297B5C6E5C745C742F2F3E3D31392E315C6E5C745C74696628617065';
wwv_flow_api.g_varchar2_table(27) := '782E7468656D6534322E7574696C2E636F6E666967415045584D736773297B5C6E5C745C745C74617065782E7468656D6534322E7574696C2E636F6E666967415045584D736773287B5C6E5C745C74202020205C746175746F4469736D6973733A207472';
wwv_flow_api.g_varchar2_table(28) := '75652C5C6E5C745C74202020205C746475726174696F6E3A207061727365496E74286475726174696F6E295C6E5C745C7420205C747D293B5C6E5C745C742F2F3C31392E315C6E5C745C747D20656C7365207B5C6E5C745C745C74617065782E6D657373';
wwv_flow_api.g_varchar2_table(29) := '6167652E7365745468656D65486F6F6B73287B5C6E5C745C745C745C746265666F726553686F773A2066756E6374696F6E28704D7367547970652C2070456C656D656E7424297B5C6E5C745C745C745C745C7469662028704D7367547970653D3D277375';
wwv_flow_api.g_varchar2_table(30) := '636365737327297B205C6E5C745C745C745C745C745C7473657454696D656F75742866756E6374696F6E28297B5C6E5C745C745C745C745C745C745C742428272E742D416C65727427292E666164654F75742827736C6F7727293B5C6E5C745C745C745C';
wwv_flow_api.g_varchar2_table(31) := '745C745C747D2C207061727365496E74286475726174696F6E29293B5C6E5C745C745C745C745C747D5C6E5C745C745C745C747D5C6E5C745C745C747D293B5C6E5C745C747D5C6E5C747D2C5C6E5C747363726F6C6C546F3A2066756E6374696F6E2873';
wwv_flow_api.g_varchar2_table(32) := '656C6563746F722C206475726174696F6E297B5C6E5C745C742F2F617065782E7468656D6534322E7574696C2E7363726F6C6C546F286964293B5C6E5C745C742F2F6368616E676564207468652064656661756C74207363726F6C6C546F2066756E6374';
wwv_flow_api.g_varchar2_table(33) := '696F6E20746F206E6F74206F6E6C792068616E646C652069642D732C5C6E5C745C742F2F62757420616E79206A51756572792073656C6563746F72206F72206A5175657279206F626A6563745C6E202020202020202076617220656C656D242C5C6E2020';
wwv_flow_api.g_varchar2_table(34) := '20202020202020202020656C656D4F66667365743B5C6E5C6E2020202020202020696628747970656F66286475726174696F6E2920213D205C226E756D6265725C22297B5C6E20202020202020205C746475726174696F6E203D203430303B5C6E202020';
wwv_flow_api.g_varchar2_table(35) := '20202020207D5C6E5C6E2020202020202020656C656D24203D2024282073656C6563746F7220293B5C6E20202020202020206966202820656C656D245B305D2029207B5C6E202020202020202020202020656C656D4F6666736574203D20656C656D242E';
wwv_flow_api.g_varchar2_table(36) := '6F666673657428292E746F70202D20617065782E7468656D652E64656661756C74537469636B79546F7028293B5C6E2020202020202020202020202428202768746D6C2C20626F6479272C20617065782E6750616765436F6E746578742420292E616E69';
wwv_flow_api.g_varchar2_table(37) := '6D617465287B5C6E202020202020202020202020202020207363726F6C6C546F703A20656C656D4F66667365745C6E2020202020202020202020207D2C206475726174696F6E293B5C6E20202020202020207D5C6E5C747D2C5C6E5C74657865633A2066';
wwv_flow_api.g_varchar2_table(38) := '756E6374696F6E28297B5C6E5C745C7476617220646154686973205C745C7420203D20746869733B5C6E5C745C7476617220706572666F726D416374696F6E203D206461546869732E616374696F6E2E61747472696275746530313B5C6E5C745C747661';
wwv_flow_api.g_varchar2_table(39) := '72206475726174696F6E205C7420203D206461546869732E616374696F6E2E61747472696275746530323B5C6E5C6E5C745C7473776974636828706572666F726D416374696F6E297B5C6E5C745C745C74636173652027636F6C6C617073656E61766D65';
wwv_flow_api.g_varchar2_table(40) := '6E75273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E636F6C6C617073654E61764D656E7528293B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027657870616E646E61766D656E75';
wwv_flow_api.g_varchar2_table(41) := '273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E657870616E644E61764D656E7528293B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027636F6C6C617073656E61766D656E756E6F';
wwv_flow_api.g_varchar2_table(42) := '646573273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E636F6C6C617073654E61764D656E754E6F64657328293B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027657870616E646E';
wwv_flow_api.g_varchar2_table(43) := '61766D656E756E6F646573273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E657870616E644E61764D656E754E6F64657328293B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C7463617365202773';
wwv_flow_api.g_varchar2_table(44) := '65746E61766D656E756E6F6465736175746F636F6C6C61707365273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E7365744E61764D656E754E6F6465734175746F436F6C6C61707365286461546869732E6163';
wwv_flow_api.g_varchar2_table(45) := '74696F6E2E6174747269627574653033203D3D20275927293B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027636F6C6C61707365636F6C6C61707369626C65726567696F6E273A5C6E5C745C745C745C746966286461546869';
wwv_flow_api.g_varchar2_table(46) := '732E616374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B5C6E5C745C745C745C745C74617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F2062652073656C656374';
wwv_flow_api.g_varchar2_table(47) := '656420666F722027202B206461546869732E616374696F6E2E616374696F6E293B5C6E5C745C745C745C747D20656C7365207B5C6E5C745C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E636F6C6C61707365436F6C6C';
wwv_flow_api.g_varchar2_table(48) := '61707369626C65526567696F6E286461546869732E6166666563746564456C656D656E7473293B5C6E5C745C745C745C747D5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027657870616E64636F6C6C61707369626C65726567';
wwv_flow_api.g_varchar2_table(49) := '696F6E273A5C6E5C745C745C745C746966286461546869732E616374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B5C6E5C745C745C745C745C74617065782E64656275672E6572726F72282741207265';
wwv_flow_api.g_varchar2_table(50) := '67696F6E206E6565647320746F2062652073656C656374656420666F722027202B206461546869732E616374696F6E2E616374696F6E293B5C6E5C745C745C745C747D20656C7365207B5C6E5C745C745C745C745C74617065785574696C732E756E6976';
wwv_flow_api.g_varchar2_table(51) := '657273616C5468656D652E657870616E64436F6C6C61707369626C65526567696F6E286461546869732E6166666563746564456C656D656E7473293B5C6E5C745C745C745C747D5C6E5C745C745C745C74627265616B3B5C6E5C745C745C746361736520';
wwv_flow_api.g_varchar2_table(52) := '276D6178696D697A61626C65726567696F6E6D6178696D697A65273A5C6E5C745C745C745C746966286461546869732E616374696F6E2E6166666563746564456C656D656E74735479706520213D2027524547494F4E27297B5C6E5C745C745C745C745C';
wwv_flow_api.g_varchar2_table(53) := '74617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F2062652073656C656374656420666F722027202B206461546869732E616374696F6E2E616374696F6E293B5C6E5C745C745C745C747D20656C7365207B5C6E5C';
wwv_flow_api.g_varchar2_table(54) := '745C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E6D6178696D697A654D6178696D697A61626C65526567696F6E286461546869732E6166666563746564456C656D656E7473293B5C6E5C745C745C745C747D5C6E5C74';
wwv_flow_api.g_varchar2_table(55) := '5C745C745C74627265616B3B5C6E5C745C745C746361736520276D6178696D697A61626C65726567696F6E726573746F7265273A5C6E5C745C745C745C746966286461546869732E616374696F6E2E6166666563746564456C656D656E74735479706520';
wwv_flow_api.g_varchar2_table(56) := '213D2027524547494F4E27297B5C6E5C745C745C745C745C74617065782E64656275672E6572726F7228274120726567696F6E206E6565647320746F2062652073656C656374656420666F722027202B206461546869732E616374696F6E2E616374696F';
wwv_flow_api.g_varchar2_table(57) := '6E293B5C6E5C745C745C745C747D20656C7365207B5C6E5C745C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E726573746F72654D6178696D697A61626C65526567696F6E286461546869732E6166666563746564456C';
wwv_flow_api.g_varchar2_table(58) := '656D656E7473293B5C6E5C745C745C745C747D5C6E5C745C745C745C74627265616B3B5C6E5C745C745C746361736520277363726F6C6C746F273A5C6E5C745C745C745C742F2F6966206E6F20416666656374656420456C656D656E7420776173207365';
wwv_flow_api.g_varchar2_table(59) := '6C65637465642C206461546869732E6166666563746564456C656D656E74732077696C6C2028666F7220736F6D6520726561736F6E292062652074686520646F63756D656E74206F626A6563745C6E5C745C745C745C742F2F736F20776520636865636B';
wwv_flow_api.g_varchar2_table(60) := '20746865206166666563746564456C656D656E7473547970652077686963682077696C6C206265206E756C6C5C6E5C745C745C745C742F2F6461546869732E6166666563746564456C656D656E74732E6C656E6774682077696C6C206265203020696620';
wwv_flow_api.g_varchar2_table(61) := '7468652070726F76696465642073656C6563746F722072657475726E73206E6F206F626A656374735C6E5C745C745C745C74696628216461546869732E616374696F6E2E6166666563746564456C656D656E747354797065207C7C206461546869732E61';
wwv_flow_api.g_varchar2_table(62) := '66666563746564456C656D656E74732E6C656E677468203D3D2030297B5C6E5C745C745C745C745C74617065782E64656275672E6572726F7228274E6F20416666656374656420456C656D656E7420666F756E6420666F722027202B206461546869732E';
wwv_flow_api.g_varchar2_table(63) := '616374696F6E2E616374696F6E293B5C6E5C745C745C745C747D20656C7365207B5C6E5C745C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E7363726F6C6C546F286461546869732E6166666563746564456C656D656E';
wwv_flow_api.g_varchar2_table(64) := '74732E65712830292C207061727365496E74286475726174696F6E29293B5C6E5C745C745C745C747D5C6E5C745C745C745C74627265616B3B5C6E5C745C745C74636173652027636F6E666967757265737563636573736E6F74696669636174696F6E64';
wwv_flow_api.g_varchar2_table(65) := '75726174696F6E273A5C6E5C745C745C745C74617065785574696C732E756E6976657273616C5468656D652E636F6E666967757265537563636573734E6F74696669636174696F6E4475726174696F6E287061727365496E74286475726174696F6E2929';
wwv_flow_api.g_varchar2_table(66) := '3B5C6E5C745C745C745C74627265616B3B5C6E5C745C745C7464656661756C743A5C6E5C745C745C745C74617065782E64656275672E6572726F722827416374696F6E205C2227202B20706572666F726D416374696F6E202B20275C2220666F72202720';
wwv_flow_api.g_varchar2_table(67) := '2B206461546869732E616374696F6E2E616374696F6E202B2027206E6F742068616E646C656427293B5C6E5C745C747D5C6E5C747D5C6E7D3B5C6E5C6E617065782E6A51756572792877696E646F77292E6F6E28276170657877696E646F77726573697A';
wwv_flow_api.g_varchar2_table(68) := '6564272C2066756E6374696F6E2829207B5C6E5C74242827626F647927292E74726967676572282761752D75742D6170657877696E646F77726573697A656427293B5C6E7D293B5C6E5C6E617065782E6A51756572792877696E646F77292E6F6E282774';
wwv_flow_api.g_varchar2_table(69) := '68656D6534327265616479272C2066756E6374696F6E2829207B5C6E5C74242827626F647927292E74726967676572282761752D75742D7468656D653432726561647927293B5C6E7D293B5C6E5C6E617065782E6A5175657279282723745F547265654E';
wwv_flow_api.g_varchar2_table(70) := '617627292E6F6E28277468656D6534326C61796F75746368616E676564272C2066756E6374696F6E286576656E742C206F626A29207B5C6E5C746966286F626A2E616374696F6E203D3D2027657870616E6427297B5C6E5C745C74242827626F64792729';
wwv_flow_api.g_varchar2_table(71) := '2E74726967676572282761752D75742D7468656D6534326E61766D656E75657870616E64656427293B5C6E5C747D20656C736520696620286F626A2E616374696F6E203D3D2027636F6C6C6170736527297B5C6E5C745C74242827626F647927292E7472';
wwv_flow_api.g_varchar2_table(72) := '6967676572282761752D75742D7468656D6534326E61766D656E75636F6C6C617073656427293B5C6E5C747D5C6E7D293B5C6E225D2C2266696C65223A227363726970742E6A73227D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(54932252238674850)
,p_plugin_id=>wwv_flow_api.id(28946015191217694891)
,p_file_name=>'js/script.js.map'
,p_mime_type=>'application/octet-stream'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
